@@ -156,3 +156,26 @@ def use(context, widget, **kwargs):
 @register.filter
 def flat_attrs(attrs):
     return flatatt(attrs)
+
+@register.simple_tag(takes_context=True)
+def render_form(context, form, template, **kwargs):
+    '''
+    Render an entire form in one go.
+    '''
+
+    kwargs['form'] = form
+    # Add blocks so field tags will work
+    kwargs['formulation'] = blocks = resolve_blocks(template, context)
+
+    row_block = blocks.get_block('row')
+
+    rows = []
+    with ContextDict(context, kwargs) as context:
+        for field in form:
+            context['field'] = field
+            rows.append(row_block.render(context))
+
+    kwargs['rows'] = rows
+    with ContextDict(context, kwargs) as context:
+        return blocks.get_block('form').render(context)
+
